summaryrefslogtreecommitdiff
path: root/java/com/android/dialer/calllog/ui/menu
diff options
context:
space:
mode:
authorzachh <zachh@google.com>2018-03-30 17:12:55 -0700
committerCopybara-Service <copybara-piper@google.com>2018-03-30 17:14:03 -0700
commit07206e2c106eec909fd38c16a66957a5e00372de (patch)
treefef38ad919265f8179b14ae01fdb6023e6024429 /java/com/android/dialer/calllog/ui/menu
parentf6be61727fba9b0fdac3b9d69588e4467f861552 (diff)
Use IS_READ instead of NEW in new call log.
We want to be more consistent with other usages of NEW in the app, i.e. NEW should be used primarily by notifications. Bug: 74821515 Test: unit PiperOrigin-RevId: 191139559 Change-Id: Ib6fbead8b5589aedd881db26a07f7daed4d83543
Diffstat (limited to 'java/com/android/dialer/calllog/ui/menu')
-rw-r--r--java/com/android/dialer/calllog/ui/menu/NewCallLogMenu.java6
1 files changed, 3 insertions, 3 deletions
diff --git a/java/com/android/dialer/calllog/ui/menu/NewCallLogMenu.java b/java/com/android/dialer/calllog/ui/menu/NewCallLogMenu.java
index dabb9bbe4..3869e78c3 100644
--- a/java/com/android/dialer/calllog/ui/menu/NewCallLogMenu.java
+++ b/java/com/android/dialer/calllog/ui/menu/NewCallLogMenu.java
@@ -35,9 +35,9 @@ public final class NewCallLogMenu {
HistoryItemActionBottomSheet.show(
context, BottomSheetHeader.fromRow(context, row), Modules.fromRow(context, row));
- // If the user opens the bottom sheet for a new call, clear the notifications and make the row
- // not bold immediately. To do this, mark all of the calls in group as not new.
- if (row.getIsNew() && row.getCallType() == Calls.MISSED_TYPE) {
+ // If the user opens the bottom sheet for an unread call, clear the notifications and make the
+ // row not bold immediately. To do this, mark all of the calls in group as read.
+ if (!row.getIsRead() && row.getCallType() == Calls.MISSED_TYPE) {
Futures.addCallback(
CallLogComponent.get(context)
.getClearMissedCalls()